## 美股列表

接口：us_basic

描述：获取美股列表信息

限量：单次最大6000，可分页提取

积分：120积分可以试用，5000积分有正式权限

输入参数

| 名称 | 类型 | 必选 | 描述 | 示例 |
| --- | --- | --- | --- | --- |
| ts_code | str | N | 股票代码 | AAPL（苹果） |
| classify | str | N | 股票分类 | ADR/GDR/EQ |
| offset | str | N | 开始行数 | 1：第一行 |
| limit | str | N | 每页最大行数 | 500：每页500行 |

输出参数

| 名称 | 类型 | 默认显示 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | Y | 美股代码 |
| name | str | Y | 中文名称 |
| enname | str | N | 英文名称 |
| classify | str | Y | 分类ADR/GDR/EQ |
| list_date | str | Y | 上市日期 |
| delist_date | str | Y | 退市日期 |

接口示例

```python
pro = ts.pro_api()

#获取默认美国股票基础信息，单次6000行
df = pro.us_basic()
```

数据示例

```python
ts_code  name classify list_date delist_date
0       ONCY  None      EQT  20011005        None
```